@@ -35,6 +35,7 @@ from calculate.core.utils.cl_backup_restore import ClBackupRestoreAction
 from calculate.core.server.func import WsdlBase
 from calculate.core.utils.cl_core_setup import ClCoreSetupAction
 from calculate.core.utils.cl_core_patch import ClCorePatchAction
+from calculate.core.utils.cl_config import ClConfigAction
 from calculate.core.utils.cl_core_dispatch import ClCoreDispatchAction
 from calculate.core.utils.cl_core_view_cert import ClCoreViewCert
 from calculate.core.utils.cl_core_group import (
@@ -618,6 +619,44 @@ class Wsdl(WsdlBase):
                                         'cl_variable_show'),
                                     next_label=_("Show"))]},
         #
+        # Выполнить настройку пакета (cl-config)
+        #
+        {
+            # идентификатор метода
+            'method_name': "core_config",
+            # категория метода
+            'category': __('Configuration'),
+            # заголовок метода
+            'title': __("Config"),
+            # иконка для графической консоли
+            'image': None,
+            # метода нет в графической консоли
+            'gui': False,
+            # консольная команда
+            'command': 'cl-config',
+            # права для запуска метода
+            'rights': ['configure'],
+            # объект содержащий модули для действия
+            'logic': {'UpdateConfigs': setup_package.UpdateConfigs},
+            # описание действия
+            'action': ClConfigAction,
+            # объект переменных
+            'datavars': "core",
+            'native_error': (VariableError, DataVarsError,
+                             setup_package.SetupPackageError),
+            # значения по умолчанию для переменных этого метода
+            'setvars': {'cl_action!': 'config', 'cl_verbose_set': "on"},
+            # описание груп (список лямбда функций)
+            'groups': [
+                lambda group: group(_("Configure a package"),
+                                    normal=('cl_core_pkg_name',),
+                                    expert=('cl_core_pkg_category',
+                                            'cl_core_pkg_version_opt',
+                                            'cl_core_pkg_slot_opt',
+                                            'cl_templates_locate',
+                                            'cl_verbose_set'),
+                                    next_label=_("Run"))]},
+        #
         # отобразить переменные
         #
         {
